@@ -20,6 +20,7 @@ class BaumerCameraInlet(CameraInlet):
     def __init__(self, config: CameraConfiguration):
         super().__init__(config)
         self.camera_status.initialised = False
+        self.current_frame = None
 
     def __del__(self):
         if self.camera_object is not None:
@@ -31,7 +32,7 @@ class BaumerCameraInlet(CameraInlet):
             self.camera_object.SetSynchronFeatureMode(True)
         super().apply_configuration()
 
-    def set_parameter(self, parameter: str, requested_value) -> bool:
+    def set_parameter(self, parameter: str, requested_value: object) -> bool:
         """
         Sets a single parameter of the Baumer camera.
         :param parameter: str: Feature name according to neoAPI documentation.
@@ -41,20 +42,20 @@ class BaumerCameraInlet(CameraInlet):
         :return: bool: True if the feature is set successfully, False - if not
         """
         if DEBUG:
-            print('Set parameter %s to %s' % (parameter, requested_value))
+            logging.info('Parameter (' + parameter + ') is set to ' + str(requested_value))
             return True
 
         if not self.camera_object.HasFeature(parameter):
             logging.warning('Feature %s not detected' % parameter)
             return False
         else:
-            logging.info('Feature %s detected' % parameter)
+            logging.debug('Feature %s detected' % parameter)
 
         if not self.camera_object.IsWritable(parameter):
             logging.warning('Feature %s not available' % parameter)
             return False
         else:
-            logging.info('Feature %s writable' % parameter)
+            logging.debug('Feature %s writable' % parameter)
 
         try:
             self.camera_object.SetFeature(parameter, requested_value)
@@ -82,7 +83,7 @@ class BaumerCameraInlet(CameraInlet):
         logging.info(self.get_details())
 
     def _connect_attempt(self):
-        logging.info('Trying to connect to capturing device...')
+        logging.debug('Trying to connect to capturing device...')
         try:
             self.camera_object.Connect()
         except neoapi.NotConnectedException as exc:
@@ -96,7 +97,7 @@ class BaumerCameraInlet(CameraInlet):
             return
 
         self.camera_object = None
-        logging.info('Captured device released')
+        logging.debug('Captured device released')
         self.camera_status.initialised = True
 
     def retrieve_data(self):
@@ -105,7 +106,7 @@ class BaumerCameraInlet(CameraInlet):
         if not self.config.is_valid():
             status = CapturingStatus(100)
             data_chunk.add_status(status)
-            print('Step %s : No execution due to invalid configuration' % self.name)
+            logging.error('Step %s : No execution due to invalid configuration' % self.name)
             return [data_chunk]
 
         if not self.camera_status.initialised:
@@ -127,43 +128,46 @@ class BaumerCameraInlet(CameraInlet):
             return [data_chunk]
 
         if self.camera_status.capturing:
-            status = CapturingStatus(2)
-            data_chunk.add_status(status)
-            logging.warning(status.get_message())
-            self.camera_status.initialised = False
-            return [data_chunk]
-
-        self.camera_status.capturing = True
-        if DEBUG:
-            print('Connect')
-            self.camera_status.initialised = True
-            frame_raw = True
-            frame_np = np.random.rand(640, 480, 3)
+            if self.current_frame:
+                frame_raw = True
+                frame_np = self.current_frame
+            else:
+                status = CapturingStatus(2)
+                data_chunk.add_status(status)
+                logging.warning(status.get_message())
+                self.camera_status.initialised = False
+                return [data_chunk]
         else:
-            frame_raw = self.camera_object.GetImage(GET_IMAGE_TIMEOUT)
-            frame_np = frame_raw.GetNPArray()
+            self.camera_status.capturing = True
+            if DEBUG:
+                self.camera_status.initialised = True
+                frame_raw = True
+                frame_np = np.random.rand(2500, 2500, 3)
+            else:
+                frame_raw = self.camera_object.GetImage(GET_IMAGE_TIMEOUT)
+                frame_np = frame_raw.GetNPArray()
+                self.current_frame = frame_np
+            self.camera_status.capturing = False
 
-        self.camera_status.capturing = False
-
-        if frame_raw is not None:
-            data_chunk.add_data(DataChunkImage('frame', frame_np, 'base64_png'))
-
-            status = CapturingStatus(0)
-            data_chunk.add_status(status)
-            logging.warning(status.get_message())
-
-            data_chunk.add_metadata(MetadataChunkData('colormap', 'BGR'))
-            data_chunk.add_metadata(MetadataChunkData('shape', frame_np.shape))
-            for metadata_variable, metadata_value in self.config.metadata.items():
-                data_chunk.add_metadata(MetadataChunkData(metadata_variable, metadata_value))
-            return [data_chunk]
-        else:
+        if frame_raw is None:
             status = CapturingStatus(99)
             data_chunk.add_status(status)
             logging.warning(status.get_message())
             self.camera_status.initialised = False
             return [data_chunk]
 
+        data_chunk.add_data(DataChunkImage('frame', frame_np, 'base64_png'))
+
+        status = CapturingStatus(0)
+        data_chunk.add_status(status)
+        logging.warning(status.get_message())
+
+        data_chunk.add_metadata(MetadataChunkData('colormap', self.get_pixel_format()))
+        data_chunk.add_metadata(MetadataChunkData('shape', frame_np.shape))
+        for metadata_variable, metadata_value in self.config.metadata.items():
+            data_chunk.add_metadata(MetadataChunkData(metadata_variable, metadata_value))
+        return [data_chunk]
+
     def execute(self):
         return super().execute()
 
@@ -177,8 +181,17 @@ class BaumerCameraInlet(CameraInlet):
     def get_configuration(self):
         if not self.camera_object.IsConnected():
             return {}
-        feature_list = ['ExposureAuto', 'ExposureTime', 'Gain', 'GainAuto', 'Gamma', 'Width', 'Height', 'OffsetX', 'OffsetY', 'BalanceWhiteAuto', 'PixelFormat']
+        feature_list = ['ExposureAuto', 'ExposureTime', 'Gain', 'GainAuto', 'Gamma',
+                        'Width', 'Height', 'OffsetX', 'OffsetY', 'BalanceWhiteAuto', 'PixelFormat']
         feature_dict = {}
         for f_name in feature_list:
             feature_dict[f_name] = eval(f"self.camera_object.f.{f_name}.value")
         return feature_dict
+
+    def get_pixel_format(self):
+        if not self.camera_object.IsConnected():
+            return None
+        try:
+            return self.camera_object.f.PixelFormat.value
+        except Exception as exc:
+            return None
