@@ -15,9 +15,9 @@ class Inlet(ABC):
     @abstractmethod
     def execute(self):
         begin_time = time.time()
-        logging.debug('Inlet ' + self.name + ' (' + self.type + ') execution began')
+        logging.debug(f'Inlet {self.name} ({self.type}) execution began')
         inlet_result = self.retrieve_data()
         end_time = time.time()
         exec_duration = end_time - begin_time
-        logging.debug('Inlet ' + self.name + ' (' + self.type + ') execution finished, execution time:' + str(exec_duration))
+        logging.info(f'Inlet {self.name} ({self.type}) execution finished (exec time {exec_duration:.3f} s)')
         return inlet_result
